if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x usr/bin/gtk-update-icon-cache ]; then
    chroot . /usr/bin/gtk-update-icon-cache /usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi

( cd usr/lib ; rm -rf libgcr-3.so )
( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-3.so )
( cd usr/lib ; rm -rf libgck-1.so.0 )
( cd usr/lib ; ln -sf libgck-1.so.0.0.0 libgck-1.so.0 )
( cd usr/lib ; rm -rf libgcr-3.so.1.0.0 )
( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-3.so.1.0.0 )
( cd usr/lib ; rm -rf libgcr-3.so.1 )
( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-3.so.1 )
( cd usr/lib ; rm -rf libgck-1.so )
( cd usr/lib ; ln -sf libgck-1.so.0.0.0 libgck-1.so )
( cd usr/lib ; rm -rf libgcr-base-3.so )
( cd usr/lib ; ln -sf libgcr-base-3.so.1.0.0 libgcr-base-3.so )
( cd usr/lib ; rm -rf libgcr-ui-3.so )
( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-ui-3.so )
( cd usr/lib ; rm -rf libgcr-base-3.so.1 )
( cd usr/lib ; ln -sf libgcr-base-3.so.1.0.0 libgcr-base-3.so.1 )
( cd usr/lib ; rm -rf libgcr-ui-3.so.1 )
( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-ui-3.so.1 )
